package com.denachina.pickle.ui;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;

/**
 * Created by he.b.wang on 16/5/5.
 */
public class ArrowView extends View {

    private static final String TAG = ArrowView.class.getSimpleName();
    private int[] mAttrs = {android.R.attr.background};
    private Drawable background;

    public ArrowView(Context context, AttributeSet attrs) {
        super(context, attrs);
        TypedArray typedArray = context.obtainStyledAttributes(attrs, mAttrs);
        background = typedArray.getDrawable(0);
        Log.i(TAG, "background:" + background);
    }

    @Override
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN) {
            setBackground(null);
        } else {
            setBackgroundColor(getResources().getColor(android.R.color.transparent));
        }
        canvas.drawARGB(0, 0, 0, 0);
        Path path = new Path();
        int width = getWidth();
        int height = getHeight();
        Log.i(TAG, "width:" + width);
        Log.i(TAG, "height:" + height);
        path.moveTo(0, 0);
        path.lineTo(width, 0);
        path.lineTo(width / 2, height);
        path.lineTo(0, 0);
        Rect rect = new Rect(0, 0, width, height);
        Paint paint = new Paint();
        canvas.drawPath(path, paint);
        Bitmap bitmap = createBitmap(rect);
        paint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.SRC_IN));
        canvas.drawBitmap(bitmap, rect, rect, paint);
        bitmap.recycle();
    }

    public Bitmap createBitmap(Rect rect) {
        int width = getWidth();
        int height = getHeight();
        Bitmap b = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
        Canvas c = new Canvas(b);
        background.setBounds(rect);
        background.draw(c);
        Rect r = background.getBounds();
        Log.i(TAG, "width:" + r.width());
        return b;
    }

}
